==> huaweicloudsdkapm-3.1.136-py2.py3-none-any.whl: huaweicloudsdkapm/v1/model/create_business_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateBusinessResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'int',
        'ok': 'str'
    }

    attribute_map = {
        'id': 'id',
        'ok': 'ok'
    }

    def __init__(self, id=None, ok=None):
        """CreateBusinessResponse

        The model defined in huaweicloud sdk

        :param id: 应用的id
        :type id: int
        :param ok: 
        :type ok: str
        """
        
        super(CreateBusinessResponse, self).__init__()

        self._id = None
        self._ok = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if ok is not None:
            self.ok = ok

    @property
    def id(self):
        """Gets the id of this CreateBusinessResponse.

        应用的id

        :return: The id of this CreateBusinessResponse.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CreateBusinessResponse.

        应用的id

        :param id: The id of this CreateBusinessResponse.
        :type id: int
        """
        self._id = id

    @property
    def ok(self):
        """Gets the ok of this CreateBusinessResponse.

        :return: The ok of this CreateBusinessResponse.
        :rtype: str
        """
        return self._ok

    @ok.setter
    def ok(self, ok):
        """Sets the ok of this CreateBusinessResponse.

        :param ok: The ok of this CreateBusinessResponse.
        :type ok: str
        """
        self._ok = ok

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateBusinessResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkapm-3.1.148-py2.py3-none-any.whl: huaweicloudsdkapm/v1/model/create_business_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateBusinessResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'int',
        'ok': 'str'
    }

    attribute_map = {
        'id': 'id',
        'ok': 'ok'
    }

    def __init__(self, id=None, ok=None):
        r"""CreateBusinessResponse

        The model defined in huaweicloud sdk

        :param id: 应用的id
        :type id: int
        :param ok: 
        :type ok: str
        """
        
        super(CreateBusinessResponse, self).__init__()

        self._id = None
        self._ok = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if ok is not None:
            self.ok = ok

    @property
    def id(self):
        r"""Gets the id of this CreateBusinessResponse.

        应用的id

        :return: The id of this CreateBusinessResponse.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this CreateBusinessResponse.

        应用的id

        :param id: The id of this CreateBusinessResponse.
        :type id: int
        """
        self._id = id

    @property
    def ok(self):
        r"""Gets the ok of this CreateBusinessResponse.

        :return: The ok of this CreateBusinessResponse.
        :rtype: str
        """
        return self._ok

    @ok.setter
    def ok(self, ok):
        r"""Sets the ok of this CreateBusinessResponse.

        :param ok: The ok of this CreateBusinessResponse.
        :type ok: str
        """
        self._ok = ok

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateBusinessResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
